@@ -1,4 +1,4 @@
-from pm4py.visualization.graphs.versions import cases, attributes, dates
+from pm4py.visualization.graphs.variants import cases, attributes, dates
 from pm4py.visualization.graphs.util.common import save, view, matplotlib_view
 from enum import Enum
 from pm4py.util import exec_utils
